@@ -8,7 +8,7 @@ use base qw(Oryx::Association::Array);
 our $DEBUG = 0;
 
 sub create {
-    my ($self, $proto) = @_;
+    my ($self, $proto, $param) = @_;
 }
 
 sub retrieve {
@@ -112,3 +112,32 @@ sub store {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+Oryx::DBM::Association::Array - DBM implementation or array associations
+
+=head1 SYNOPSIS
+
+See L<Oryx::Association::Array>.
+
+=head1 DESCRIPTION
+
+This class handles the implementation of array associations for connections using L<Oryx::DBM>.
+
+=head1 SEE ALSO
+
+L<Oryx>, L<Oryx::DBM>, L<Oryx::Association::Array>
+
+=head1 AUTHOR
+
+Richard Hundt E<lt>richard NO SPAM AT protea-systems.comE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2005 Richard Hundt.
+
+This library is free software and may be used under the same terms as Perl itself.
+
+=cut
