@@ -3,7 +3,7 @@ package Oryx::DBM::Association::Reference;
 use base qw(Oryx::Association::Reference);
 
 sub create {
-    my ($self, $proto) = @_;
+    my ($self, $proto, $param) = @_;
 }
 
 sub retrieve {
@@ -46,3 +46,32 @@ sub construct {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+Oryx::DBM::Association::Reference - DBM implementation of reference associations
+
+=head1 SYNOPSIS
+
+See L<Oryx::Association::Reference>.
+
+=head1 DESCRIPTION
+
+This class implements the reference association for classes stored within L<Oryx::DBM> connections.
+
+=head1 SEE ALSO
+
+L<Oryx>, L<Oryx::DBM>, L<Oryx::Association::Reference>
+
+=head1 AUTHOR
+
+Richard Hundt E<lt>richard NO SPAM AT protea-systems.comE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2005 Richard Hundt.
+
+This library is free software and may be used under the same terms as Perl itself.
+
+=cut
